<?php
/** Novial (Novial)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Chrisportelli
 * @author MF-Warburg
 * @author Malafaya
 * @author Nov ialiste
 * @author nov.wikipedia.org sysops
 */

$messages = array(
# Dates
'sunday'        => 'sundie',
'monday'        => 'lundie',
'tuesday'       => 'mardie',
'wednesday'     => 'merkurdie',
'thursday'      => 'jodie',
'friday'        => 'venerdie',
'saturday'      => 'saturdie',
'sun'           => 'sun',
'mon'           => 'lun',
'tue'           => 'mar',
'wed'           => 'mer',
'thu'           => 'jod',
'fri'           => 'ven',
'sat'           => 'sat',
'january'       => 'januare',
'february'      => 'februare',
'march'         => 'marte',
'april'         => 'aprile',
'may_long'      => 'maye',
'june'          => 'june',
'july'          => 'julie',
'august'        => 'auguste',
'september'     => 'septembre',
'october'       => 'oktobre',
'november'      => 'novembre',
'december'      => 'desembre',
'january-gen'   => 'de januare',
'february-gen'  => 'de februare',
'march-gen'     => 'de marte',
'april-gen'     => 'de aprile',
'may-gen'       => 'de maye',
'june-gen'      => 'de june',
'july-gen'      => 'de julie',
'august-gen'    => 'de auguste',
'september-gen' => 'de septembre',
'october-gen'   => 'de oktobre',
'november-gen'  => 'de novembre',
'december-gen'  => 'de desembre',
'jan'           => 'jan',
'feb'           => 'feb',
'mar'           => 'mar',
'apr'           => 'apr',
'may'           => 'maye',
'jun'           => 'jun',
'jul'           => 'jul',
'aug'           => 'aug',
'sep'           => 'sep',
'oct'           => 'okt',
'nov'           => 'nov',
'dec'           => 'des',

# Categories related messages
'pagecategories'  => '{{PLURAL:$1|Kategorie|Kategories}}',
'category_header' => 'Artikles in kategorie "$1"',
'subcategories'   => 'Subkategories',

'about'         => 'Pri',
'article'       => 'Pagine de kontenaje',
'newwindow'     => '(aperta in novi fenestre)',
'cancel'        => 'Nihilisa',
'moredotdotdot' => 'Plu...',
'mypage'        => 'Men pagine',
'mytalk'        => 'Men parla-pagine',
'anontalk'      => 'Parlo por disi IP',
'navigation'    => 'Navigatione',
'and'           => '&#32;e',

# Cologne Blue skin
'qbfind'         => 'Trova',
'qbedit'         => 'Modifika',
'qbpageoptions'  => 'Disi pagine',
'qbmyoptions'    => 'Men pagines',
'qbspecialpages' => 'Spesial pagines',

'returnto'         => 'Rivada a $1.',
'tagline'          => 'Fro {{SITENAME}}',
'help'             => 'Helpo',
'search'           => 'Sercha',
'searchbutton'     => 'Sercha',
'go'               => 'Vada',
'searcharticle'    => 'Vada',
'history'          => 'Historie del pagine',
'history_short'    => 'Historie',
'info_short'       => 'Informatione',
'printableversion' => 'Printindi versione',
'permalink'        => 'Permananti linke',
'print'            => 'Printa',
'edit'             => 'Immodifika',
'editthispage'     => 'Modifika disi pagine',
'delete'           => 'Ekarta',
'deletethispage'   => 'Ekarta disi pagine',
'protect'          => 'Protekte',
'protectthispage'  => 'Protekte disi pagine',
'newpage'          => 'Novi pagine',
'talkpage'         => 'Diskuse disi pagine',
'talkpagelinktext' => 'Diskusione',
'specialpage'      => 'Spesial Pagine',
'articlepage'      => 'Regarda pagine de kontenaje',
'talk'             => 'Diskusione',
'toolbox'          => 'Utensiles',
'userpage'         => 'Vida useren pagine',
'imagepage'        => 'Regarda imajal pagine',
'mediawikipage'    => 'Regarda mesajal pagine',
'templatepage'     => 'Vida shablonal pagine',
'categorypage'     => 'Regarda kategorial pagine',
'otherlanguages'   => 'Altri lingues',
'lastmodifiedat'   => 'Disi pagine blid lastim modifika: $2 ye $1.',
'jumptonavigation' => 'navigatione',
'jumptosearch'     => 'sercha',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Pri {{SITENAME}}',
'aboutpage'            => 'Project:Pri',
'currentevents'        => 'Nuni eventes',
'currentevents-url'    => 'Project:Nuni eventes',
'edithelp'             => 'Helpo pri modifiko de pagines',
'helppage'             => 'Help:Kontenaje',
'mainpage'             => 'Chefi pagine',
'mainpage-description' => 'Chefi pagine',
'portal'               => 'Li komun chambre',
'portal-url'           => 'Project:Li komun chambre',

'badaccess' => 'Permisione erore',

'youhavenewmessages'      => 'Vu have $1 ($2).',
'newmessageslink'         => 'novi mesajes',
'newmessagesdifflink'     => 'lasti chanjo',
'youhavenewmessagesmulti' => 'Vu have novi mesajes pri $1',
'editsection'             => 'modifika',
'editold'                 => 'modifika',
'restorelink'             => '{{PLURAL:$1|unu ekartati modifiko|$1 ekartati modifikos}}',
'red-link-title'          => '$1 (pagine non exista)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Artikle',
'nstab-user'      => 'Useren pagine',
'nstab-special'   => 'Spesial pagine',
'nstab-project'   => 'Projetal pagine',
'nstab-mediawiki' => 'Mesaje',
'nstab-template'  => 'Shablone',
'nstab-help'      => 'Helpo-pagine',
'nstab-category'  => 'Kategorie',

# General errors
'error'        => 'Erore',
'badtitle'     => 'Mali title',
'badtitletext' => 'Li pregati pagine esed non-valid, vakui, o non-korektim linkat inter-lingue o inter-wiki title. Lu povud kontena un o plusi karakteres kel on non pove usa in titles.',

# Login and logout pages
'logouttext'                 => "'''Vu es nun eksignatat.'''

Vu pove kontinua usa {{SITENAME}} anonimim, o vu pove riensignata kom li sami o altri usere.",
'yourname'                   => 'Usere-nome:',
'yourpassword'               => 'Pasa-vorde:',
'remembermypassword'         => 'Memora men pasa-vorde (kun kuke)',
'login'                      => 'Ensignata',
'loginprompt'                => 'Vu mus lasa cookies de ensignata en {{SITENAME}}.',
'userlogin'                  => 'Ensignata / krea usere-registre',
'logout'                     => 'Eksignata',
'userlogout'                 => 'Eksignata',
'notloggedin'                => 'Non ensignatat',
'nologin'                    => "Ob vu non have registre? '''$1'''.",
'nologinlink'                => 'Krea usere-registre',
'gotaccountlink'             => 'Ensignata',
'loginerror'                 => 'Erore de ensignato',
'loginsuccesstitle'          => 'Ensignato suksesosi',
'loginsuccess'               => "'''Vu es nun ensignatat a {{SITENAME}} nomisat \"\$1\".'''",
'mailmypassword'             => 'E-posta men pasa-vorde',
'acct_creation_throttle_hit' => 'Vu ha ja krea $1 registres. Regretindim vu non pove krea plusu.',
'accountcreated'             => 'Registre kreat',
'accountcreatedtext'         => 'Li usere-registre por $1 ha bli krea.',

# Edit page toolbar
'bold_sample'  => 'Diki texte',
'image_sample' => 'Exemple.jpg',

# Edit pages
'summary'               => 'Resume:',
'minoredit'             => 'Dise es mikri modifiko',
'watchthis'             => 'Observa disi pagine',
'savearticle'           => 'Spara pagine',
'showpreview'           => 'Montra previdatu',
'showdiff'              => 'Montra chanjos',
'blockedoriginalsource' => "Li fonte de '''$1''' bli montra subu:",
'loginreqtitle'         => 'Ensignato Postulat',
'loginreqlink'          => 'ensignata',
'accmailtitle'          => 'Pasa-vorde sendat.',
'accmailtext'           => 'Li pasa-vorde por "$1" ha bli senda a $2.',
'yourtext'              => 'Vun texte',

# History pages
'currentrev'          => 'Nuni revisione',
'currentrevisionlink' => 'Nuni revisione',
'histfirst'           => 'Maxim frui',
'histlast'            => 'Maxim resenti',

# Revision feed
'history-feed-title'       => 'Historie de revisiones',
'history-feed-description' => 'Historie de revisiones de disi pagine sur li wiki',
'history-feed-empty'       => 'Li petit pagine non exista.
Forsan lu ha bli ekarta fro li wiki, o rinomat.
Proba [[Special:Search|sercho sur li wiki]] por relatet pagines.',

# Diffs
'lineno'                  => 'Linie $1:',
'compareselectedversions' => 'Kompara selektet versiones',

# Search results
'searchresults'         => 'Resultes de sercho',
'searchresulttext'      => 'Por plu multi informatione pri sercho {{SITENAME}}, vida [[{{MediaWiki:Helppage}}|{{int:help}}]].',
'searchsubtitle'        => "Vu serchad '''[[:$1]]'''",
'searchsubtitleinvalid' => "Vu serchad '''$1'''",
'prevn'                 => 'lasti {{PLURAL:$1|$1}}',
'nextn'                 => 'sekuenti {{PLURAL:$1|$1}}',
'viewprevnext'          => 'Vida ($1 {{int:pipe-separator}} $2) ($3).',
'searchhelp-url'        => 'Help:Kontenaje',
'search-result-size'    => '$1 ({{PLURAL:$2|1 vorde|$2 vordes}})',
'showingresults'        => "Montrant subu {{PLURAL:$1|'''1''' resulte|'''$1''' resultes}} amaxim komensant fro #'''$2'''.",
'showingresultsnum'     => "Montrant subu {{PLURAL:$3|'''1''' result|'''$3''' results}} komensant fro #'''$2'''.",
'powersearch'           => 'Sercha',

# Preferences page
'preferences'           => 'Preferos',
'mypreferences'         => 'Men preferos',
'prefsnologin'          => 'Non ensignatat',
'prefsnologintext'      => 'Vu mus es [[Special:UserLogin|ensignatat]] por determina useren preferos.',
'prefs-rc'              => 'Resenti chanjos',
'searchresultshead'     => 'Sercha',
'timezoneregion-africa' => 'Afrika',

# Recent changes
'nchanges'        => '$1 {{PLURAL:$1|chanjo|chanjos}}',
'recentchanges'   => 'Resenti chanjos',
'rcnote'          => "Subu es {{PLURAL:$1| '''1''' chanje|li lasti '''$1''' chanjes}} in li lasti {{PLURAL:$2|die|'''$2''' dies}}, fro $3.",
'rcshowhideminor' => '$1 minori modifikos',
'rcshowhideanons' => '$1 anonimi useres',
'rcshowhidemine'  => '$1 men modifikos',
'rclinks'         => 'Montra lasti $1 chanjes in lasti $2 dies<br />$3',
'hist'            => 'hist',
'hide'            => 'Kasha',
'show'            => 'Montra',
'minoreditletter' => 'm',
'newpageletter'   => 'N',

# Recent changes linked
'recentchangeslinked'         => 'Afini chanjos',
'recentchangeslinked-feed'    => 'Afini chanjos',
'recentchangeslinked-toolbox' => 'Afini chanjos',

# Upload
'upload'            => 'Enporta',
'uploadnologin'     => 'Non ensignatat',
'filedesc'          => 'Resume',
'fileuploadsummary' => 'Resume:',
'watchthisupload'   => 'Observa disi pagine',

# Special:ListFiles
'listfiles_search_for'  => 'Sercha imaje nome:',
'listfiles_name'        => 'Nome',
'listfiles_user'        => 'Usere',
'listfiles_size'        => 'Grandeso (bites)',
'listfiles_description' => 'Deskriptione',

# File description page
'filehist-user' => 'Usere',
'imagelinks'    => 'Linkes',

# Random page
'randompage' => 'Arbitriari pagine',

'brokenredirects'      => 'Rupteti ri-adresos',
'brokenredirectstext'  => 'Li sekuenti ri-adresos linka a non-existanti pagines:',
'brokenredirects-edit' => 'editja',

'fewestrevisions' => 'Artikles kun minim multi revisiones',

# Miscellaneous special pages
'ncategories'             => '$1 {{PLURAL:$1|kategorie|kategories}}',
'lonelypages'             => 'Pagines kel non bli kupla',
'lonelypagestext'         => 'Disi pagines non es kuplat fro altri pagines in {{SITENAME}}.',
'uncategorizedpages'      => 'Pagines sin kategorie',
'uncategorizedcategories' => 'Kategories sin kategorie',
'uncategorizedimages'     => 'Imajes sin kategorie',
'popularpages'            => 'Popular pagines',
'mostcategories'          => 'Artikles kun maxim multi kategories',
'mostrevisions'           => 'Artikles kun maxim multi revisiones',
'shortpages'              => 'Kurti pagines',
'longpages'               => 'Longi pagines',
'deadendpages'            => 'Pagines sin kuplures',
'listusers'               => 'Liste de useres',
'newpages'                => 'Novi pagines',
'ancientpages'            => 'Maxim ansieni pagines',
'move'                    => 'Mova',
'movethispage'            => 'Mova (rinomisa) disi pagine',

# Book sources
'booksources'               => 'Libral fontes',
'booksources-search-legend' => 'Sercha libral fontes',
'booksources-go'            => 'Vada',

# Special:Log
'specialloguserlabel' => 'Usere:',

# Special:AllPages
'allpages'          => 'Omni pagines',
'alphaindexline'    => '$1 a $2',
'allarticles'       => 'Omni artikles',
'allinnamespace'    => 'Omni pagines ($1 nome-spatie)',
'allnotinnamespace' => 'Omni pagines (non in $1 nome-spatie)',
'allpagesprev'      => 'Antei',
'allpagesnext'      => 'Sekuenti',
'allpagessubmit'    => 'Vada',

# Special:Categories
'categories'         => 'Kategories',
'categoriespagetext' => 'Li sekuenti kategories exista in li wiki.
[[Special:UnusedCategories|Unused categories]] are not shown here.
Also see [[Special:WantedCategories|wanted categories]].',

# Special:LinkSearch
'linksearch-ok' => 'Sercha',

# Watchlist
'watchlist'       => 'Men liste de observos',
'mywatchlist'     => 'Men liste de observos',
'nowatchlist'     => 'Vu have nuli koses in vun liste de observos.',
'watchnologin'    => 'Non ensignatat',
'addedwatch'      => 'Adit a observa-liste',
'addedwatchtext'  => "Li pagine \"[[:\$1]]\" ha bli adi a vun [[Special:Watchlist|observa-liste]].
Futuri chanjos a disi pagine e lun asosiati Parla-pagine sal bli lista tilok, e li pagine sal apari '''diki''' in li [[Special:RecentChanges|liste de resenti chanjos]] por ke on trova lu plu fasilim.

Si vu voli plu tardim ekarta li pagine fro vun observa-liste, klikta \"Desobserva\" in li lateral kolumne.",
'watch'           => 'Observa',
'watchthispage'   => 'Observa disi pagine',
'unwatch'         => 'Desobserva',
'unwatchthispage' => 'Des-observa disi pagine',

'changed'            => 'chanjati',
'enotif_lastvisited' => 'Regarda $1 por vida omni chanjes depos vun lasti visite.',

# Delete
'confirm'         => 'Konfirma',
'excontent'       => "kontenaje esed: '$1'",
'excontentauthor' => "kontenaje esed: '$1' (e li soli kontribuere esed '[[Special:Contributions/$2|$2]]')",
'exblank'         => 'pagine esed vakui',
'actioncomplete'  => 'Akto kompleti',
'deletedarticle'  => 'ekartad "[[$1]]"',
'dellogpage'      => 'Loge de ekartos',
'dellogpagetext'  => 'Subu es liste del maxim resenti ekartos.',
'deletionlog'     => 'registre de ekartos',
'deletecomment'   => 'Resone:',

# Rollback
'revertpage' => 'Riverted modifikos da [[Special:Contributions/$2|$2]] ([[User talk:$2|Talk]]); restaurad lasti versione da [[User:$1|$1]]',

# Protect
'prot_1movedto2'      => '[[$1]] movat a [[$2]]',
'protect-legend'      => 'Konfirma protektione',
'protect-level-sysop' => 'Sisopes nur',

# Namespace form on various pages
'blanknamespace' => '(Chefi)',

# Contributions
'contributions' => 'Useren kontributiones',
'mycontris'     => 'Men kontributiones',

'sp-contributions-newbies' => 'Montra kontributiones nur de novi useres',
'sp-contributions-talk'    => 'Diskusione',
'sp-contributions-search'  => 'Sercha kontributiones',
'sp-contributions-submit'  => 'Sercha',

# What links here
'whatlinkshere'       => 'Tum kel kupla hir',
'whatlinkshere-page'  => 'Pagine:',
'whatlinkshere-links' => '← linkes',

# Block/unblock
'ipbreason'    => 'Resone:',
'badipaddress' => 'Non-valid IP adrese',
'contribslink' => 'Kontributiones',

# Move page
'movearticle'             => 'Mova pagine',
'movenologin'             => 'Non ensignatat',
'move-watch'              => 'Observa disi pagine',
'movedto'                 => 'movat a',
'1movedto2'               => '[[$1]] movat a [[$2]]',
'1movedto2_redir'         => '[[$1]] movat a [[$2]] via ri-adreso',
'movereason'              => 'Resone:',
'delete_and_move'         => 'Ekarta e mova',
'delete_and_move_confirm' => 'Yes, ekarta li pagine',
'delete_and_move_reason'  => 'Ekartat por fa spatie por movo',

# Namespace 8 related
'allmessages'        => 'Sisteme mesajes',
'allmessagesname'    => 'Nome',
'allmessagesdefault' => 'Non-spesifikati texte',
'allmessagescurrent' => 'Nuni texte',
'allmessagestext'    => 'Dise es liste de sistemen mesajes obtenabli in li MediaWiki nomal spatie.',

# Tooltip help for the actions
'tooltip-pt-mytalk'      => 'Vun parla-pagine',
'tooltip-pt-preferences' => 'Men preferos',
'tooltip-pt-logout'      => 'Eksignata',
'tooltip-p-logo'         => 'Chefi pagine',

# Info page
'infosubtitle' => 'Informatione pri pagine',

# Special:NewFiles
'ilsubmit' => 'Sercha',
'bydate'   => 'segun date',

# EXIF tags
'exif-imagewidth'       => 'Larjeso',
'exif-imagelength'      => 'Alteso',
'exif-imagedescription' => 'Title de imaje',
'exif-imageuniqueid'    => 'Unik imaje ID',

# 'all' in various places, this might be different for inflected languages
'imagelistall' => 'omnes',

# Auto-summaries
'autosumm-replace' => "Remplasant pagine kun '$1'",
'autoredircomment' => 'Ri-adresant a [[$1]]',
'autosumm-new'     => 'Novi pagine: $1',

# Special:Version
'version'                  => 'Versione',
'version-specialpages'     => 'Spesial pagines',
'version-software-version' => 'Versione',

# Special:SpecialPages
'specialpages' => 'Spesial pagines',

);
